Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/Remmina/remmina-plugins.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAllan Nordhøy <epost@anotheragency.no>2021-01-15 10:43:52 +0300
committerAntenore Gatta (tmow) <antenore@simbiosi.org>2021-01-15 10:43:52 +0300
commit6eeae920b9120c2d42ce783ff5df55bd310d8b45 (patch)
tree974d1357f7422ea867499ecad1dbf9e7def321fb
parent34ecafd61d332c471a1491a3ec63ac47dabb84a0 (diff)
Spelling: Start-up
-rw-r--r--nx_plugin.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nx_plugin.c b/nx_plugin.c
index dfe9bc6..6d8c2ef 100644
--- a/nx_plugin.c
+++ b/nx_plugin.c
@@ -415,7 +415,7 @@ static gboolean remmina_plugin_nx_start_session(RemminaProtocolWidget *gp)
app = NULL;
}else
if (g_strcmp0(cs, "Xfce") == 0) {
/* NX does not know Xfce. So we simply launch the Xfce startup program. */
type = "unix-application";
app = "startxfce4";
}else
@@ -731,7 +731,7 @@ static const RemminaProtocolSetting remmina_plugin_nx_basic_settings[] =
{ REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "password", N_("User password"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_RESOLUTION, "resolution", NULL, FALSE, GINT_TO_POINTER(1), NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "quality", N_("Quality"), FALSE, quality_list, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_COMBO, "exec", N_("Startup program"), FALSE, "GNOME,KDE,Xfce,Shadow", NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_COMBO, "exec", N_("Start-up program"), FALSE, "GNOME,KDE,Xfce,Shadow", NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -415,7 +415,7 @@ static gboolean remmina_plugin_nx_start_session(RemminaProtocolWidget *gp)
}else
if (g_strcmp0(cs, "Xfce") == 0) {
- /* NX does not know Xfce. So we simply launch the Xfce startup program. */
+ /* NX does not know Xfce. So we simply launch the Xfce start-up program. */
type = "unix-application";
app = "startxfce4";